@@ -1,7 +1,7 @@
 use strict;
 package CPAN::Reporter;
 
-our $VERSION = '1.2017';
+our $VERSION = '1.2018';
 
 use Config;
 use Capture::Tiny qw/ capture tee_merged /;
@@ -706,18 +706,23 @@ my @env_vars= qw(
     /LC_/
     /PERL/
     /_TEST/
+    CCFLAGS
     COMSPEC
     INCLUDE
+    INSTALL_BASE
     LANG
     LANGUAGE
     LD_LIBRARY_PATH
+    LDFLAGS
     LIB
+    NON_INTERACTIVE
     NUMBER_OF_PROCESSORS
     PATH
+    PREFIX
     PROCESSOR_IDENTIFIER
     SHELL
-    TEMP
     TERM
+    TEMP
     TMPDIR
 );
 
@@ -1584,7 +1589,7 @@ CPAN::Reporter - Adds CPAN Testers reporting to CPAN.pm
 
 =head1 VERSION
 
-version 1.2017
+version 1.2018
 
 =head1 SYNOPSIS
 
